#define PROGVERS "1.0"
#define AUTHORINFO "(c)2009 m.Lucarelli"
#define PROGNAME "BarPlotDemo"

#include <getopt.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#include "Fl_BarPlot.h"

#define BARCOUNT 100
#define RANGE 1000
#define NOTCH 50
#define BARCOLOR fl_rgb_color(0,150,0)
#define BGCOLOR fl_rgb_color(0,0,0)

#include <FL/Fl_Double_Window.H>


void print_usage(int exit_code)
{
	fprintf (stderr,"Usage: %s [OPTIONS] ....\n",PROGNAME);
	fprintf (stderr,"  -h  --help        Display this usage informations.\n");
	fprintf (stderr,"  -v  --version     Display version informations.\n");
	exit (exit_code);
}

int main(int argc, char* argv[])
{
	int next_option;
	
	const char* const short_options = "hv";
	
	const struct option long_options[] = {
	{ "help",     0, NULL, 'h' },
	{ "version",  0, NULL, 'v' },
	{ NULL,       0, NULL, 0   }
	};
	
	do {
		next_option = getopt_long(argc,argv,short_options,long_options,NULL);
		switch (next_option)
		{
			case 'h':   // -h o --help
				print_usage(0);
				break;
			case 'v':   // -v o --version
				fprintf(stderr,"%s %s %s\n",PROGNAME,PROGVERS,AUTHORINFO);
				exit(0);
				break;
			case '?':   // opzione invalida
				print_usage(1);
				break;
		}
	}
	while (next_option != -1);
	
	Fl::visual(FL_RGB);
	Fl_Double_Window *wMain = new Fl_Double_Window(800,600,"BarPlotDemo");
	Fl_BarPlot* plot=new Fl_BarPlot(10,10,780,580);
	wMain->resizable(plot);
	wMain->end();
	
	plot->setBars(BARCOUNT,0,RANGE);
	plot->setNotch(NOTCH);
	plot->setBarColor(BARCOLOR);
	plot->setBgColor(BGCOLOR);
	
	int i;
	for (i=0;i<BARCOUNT;i++) plot->setBarVal(i,RANGE/2);
	
	wMain->show();
	
	float r;
	while (Fl::check()){
		for (i=0;i<BARCOUNT;i++){
			r=(0.5-rand()/(float)RAND_MAX)*RANGE/10;
			r+=plot->getBarVal(i);
			if (r<0) r=0;
			else if (r>RANGE) r=RANGE;
			plot->setBarVal(i,r);
		}
		usleep(100000);
	}
	return 0;
}
